@@ -2,6 +2,8 @@ from ..utils import MetaOptions
 from ..utils.parser import FormParser, XMLParser, JSONParser, AbstractParser
 from ..utils.tools import as_tuple
 
+__all__ = 'ParserMixin',
+
 
 class ParserMeta(type):
 
@@ -12,7 +14,8 @@ class ParserMeta(type):
         cls.meta.default_parser = cls.parsers[0] if cls.parsers else None
 
         for p in cls.parsers:
-            assert issubclass(p, AbstractParser), "Parser must be subclass of AbstractParser"
+            assert issubclass(p, AbstractParser), \
+                "Parser must be subclass of AbstractParser"
             cls.meta.parsers_dict[p.media_type] = p
 
         return cls
@@ -34,7 +37,8 @@ class ParserMixin(object):
                     content_type = split[0]
                 content_type = content_type.strip()
 
-            parser = self.meta.parsers_dict.get(content_type, self.meta.default_parser)
+            parser = self.meta.parsers_dict.get(
+                content_type, self.meta.default_parser)
             data = parser(self).parse(request)
             return dict() if isinstance(data, basestring) else data
         return dict()
@@ -43,7 +47,8 @@ class ParserMixin(object):
     def determine_content(request):
         " Determine request content "
 
-        if not request.META.get('CONTENT_LENGTH', None) and not request.META.get('TRANSFER_ENCODING', None):
+        if not request.META.get('CONTENT_LENGTH', None) \
+           and not request.META.get('TRANSFER_ENCODING', None):
             return None
 
         return request.META.get('CONTENT_TYPE', None)
